import {
  get as getAccessToken,
  set as setAccessToken,
  remove as removeAccessToken,
} from './accessToken.js';

import {
  append as appendToHeaders,
  remove as removeFromHeaders,
} from '../headers.js';

describe('SSO AccessToken Service', () => {
  beforeEach(() => {
    removeFromHeaders('SSO-AccessToken');
  });

  it('Should get SSO-AccessToken from Headers when defined.', () => {
    appendToHeaders('SSO-AccessToken', 'xyz123456');
    expect(getAccessToken()).to.equal('xyz123456');
  });

  it('Should set SSO-AccessToken to Headers.', () => {
    appendToHeaders('SSO-AccessToken', 'xyz123456');
    setAccessToken('abc123');
    expect(getAccessToken()).to.equal('abc123');
  });

  it('Should not set SSO-AccessToken when parameters are not passed.', () => {
    appendToHeaders('SSO-AccessToken', 'start5678');
    setAccessToken();
    expect(getAccessToken()).to.equal('start5678');
  });

  it('Should remove SSO-AccessToken from Headers.', () => {
    appendToHeaders('SSO-AccessToken', 'start5678');
    removeAccessToken();
    expect(getAccessToken()).to.be.undefined;
  });
});
