import {
  get as getRefreshToken,
  set as setRefreshToken,
  remove as removeRefreshToken,
} from './refreshToken.js';

import {
  append as appendToHeaders,
  remove as removeFromHeaders,
} from '../headers.js';

describe('SSO RefreshToken Service', () => {
  beforeEach(() => {
    removeFromHeaders('SSO-RefreshToken');
  });

  it('Should get SSO-RefreshToken from Headers when defined.', () => {
    appendToHeaders('SSO-RefreshToken', 'xyz123456');
    expect(getRefreshToken()).to.equal('xyz123456');
  });

  it('Should set SSO-RefreshToken to Headers.', () => {
    appendToHeaders('SSO-RefreshToken', 'xyz123456');
    setRefreshToken('abc123');
    expect(getRefreshToken()).to.equal('abc123');
  });

  it('Should not set SSO-RefreshToken when parameters are not passed.', () => {
    appendToHeaders('SSO-RefreshToken', 'start5678');
    setRefreshToken();
    expect(getRefreshToken()).to.equal('start5678');
  });

  it('Should remove SSO-RefreshToken from Headers.', () => {
    appendToHeaders('SSO-RefreshToken', 'start5678');
    removeRefreshToken();
    expect(getRefreshToken()).to.be.undefined;
  });
});
